% Returns an array of all the animats in the scenario.
function SpeDesc = ...
    AddAnimatDescriptionToSpeDescription(fid, SceParams, SpeDesc)
% Updated for 3mb lib version 4.00 on 09/02/08

if SceParams.binOutConfig.speInfAndAnimatAsscn == 0
    STATANALYSIS = [];
    return
end


% Set the file pointer to the begining of the file
fseek(fid, SceParams.filePointers.animatToSpeAssoc, 'bof');

ANIDESC = struct(...
    'podIndex', 0, ... the pod's index in the species that the animat
    ...%...                belongs to.  Zero-based
    ...%'animatIndex', 0, ... the animat's index in the pod.  Zero-based
    'membership', 0, ... 0 = pod member, 1 = individual
    'szMembership', '', ...
    'focalAnimatType', 0); % 0 = animat, 1 = centroid.


%--------------------------------------------------------%
% Read in the Animat Population Description
%------------------------------------------%
% For each animat in the scenario, read in its
%   (1) species number it belongs to (indexed starting at zero)
%   (2) pod ID in the species it belongs to (indexed starting at 1)
%   (3) animat ID in the pod it belongs to
%   (4) If this animat is an individual (BOOL, 1 = individual, 0 = pod)
for n=1:SceParams.totalNumAnimats
    % Get indexing.  In the binary file indexing is zero-based so
    % add 1 because Matlab is not zero-based.
    speIndex = 1 + fread(fid, 1, 'uint16');
    ANIDESC.podIndex = 1 + fread(fid, 1, 'uint16'); % 4 bytes
    fseek(fid, 2, 'cof'); %skip past the animat's index in the pod.
    compactInf = fread(fid, 1, 'uint16');
    ANIDESC.membership = bitget(compactInf,1); % 1 = individual
    if ANIDESC.membership == 0
        ANIDESC.szMembership = 'pod member';
    else
        ANIDESC.szMembership = 'individual';
    end
    ANIDESC.focalAnimatType = bitget(compactInf,2);
    fseek(fid, 8, 'cof');% Skip over reserved space.
    
    numAnimats = SpeDesc(speIndex).numAnimats+1;
    SpeDesc(speIndex).animat(numAnimats) = ANIDESC;
    SpeDesc(speIndex).numAnimats = numAnimats;
 end


