% Updated 02/10/13 for 3mb lib version 11.xx

function animatState = ReadAnimatPopulationState(...
            fid,...             File to read from
            scenarioParams,...         Scenario parameters set up in the 3mb by
                      ...       the user at run time.
            stateSelect,...           The selected output state variables that
                  ...           the script that called this script requests
            MaxAnimatCount) ... The maximum number of animat states to
                            ... collect.

% Set the file pointer to the begining of the file
fseek(fid, scenarioParams.filePointers.animatStates, 'bof');

%-------------------------------------------------------------------------%
% Build an initial animat state data structure
%---------------------------------------------%
% The initial structure is based upon which of the state variables the 
% calling script requested as well as upon the ones set by the user of
% the 3mb application to be saved to binary file.
ANIMATSTATE = struct;

%animat unique ID
if stateSelect.id == 1 && scenarioParams.binOutConfig.animat.ID == 1
    ANIMATSTATE.id = [];
end

	% time of day.
if stateSelect.clock == 1 && scenarioParams.binOutConfig.animat.timeOfDay == 1
    ANIMATSTATE.timeOfDay = []; 
end

%coordinates
if stateSelect.coords == 1 && scenarioParams.binOutConfig.animat.coordinate == 1
    ANIMATSTATE.lat = []; 
    ANIMATSTATE.lon = [];
end

%depth
if stateSelect.depth == 1 && scenarioParams.binOutConfig.animat.depth == 1
    ANIMATSTATE.depth = [];
end

% bearing
if stateSelect.bearing == 1  && scenarioParams.binOutConfig.animat.bearing == 1
    ANIMATSTATE.bearing = []; 
end

 % dive rate
if stateSelect.diveRate == 1 && scenarioParams.binOutConfig.animat.diveRate == 1
    ANIMATSTATE.diveRate = [];
end

% travel rate
if stateSelect.travelRate == 1 && scenarioParams.binOutConfig.animat.travelRate == 1
    ANIMATSTATE.travelRate = [];
end

%cummulative acoustic exposure
if stateSelect.cExposure == 1  && scenarioParams.binOutConfig.animat.aeCmltve == 1
    ANIMATSTATE.cExposure = [];
end

%instantaneous acoustic exposure
if stateSelect.iExposure == 1 && scenarioParams.binOutConfig.animat.aeMoment == 1
    ANIMATSTATE.iExposure = [];
end

%acoustic source position angle
if stateSelect.relAngle == 1 && scenarioParams.binOutConfig.animat.aeRelAngle == 1
    ANIMATSTATE.relAngle = [];
end

%seconds in aversion
if stateSelect.secAvert == 1 && scenarioParams.binOutConfig.animat.aeTimeAvrt == 1
    ANIMATSTATE.secAvert = [];
end
	
%bathy depth at current location
if stateSelect.bathyDepth == 1 && scenarioParams.binOutConfig.animat.bathyDepth == 1
    ANIMATSTATE.bathyDepth = [];
end

%salinity at current location
if stateSelect.salinity == 1 && scenarioParams.binOutConfig.animat.salinity == 1
    ANIMATSTATE.salinity = [];
end

%temperature current location
if stateSelect.temperature == 1 && scenarioParams.binOutConfig.animat.temperature == 1 
    ANIMATSTATE.temperature = [];
end

if scenarioParams.binOutConfig.animat.packedData == 1
    %current behavior
    if stateSelect.behavior == 1
        ANIMATSTATE.behavior = [];
    end

    %threshold flag
    if stateSelect.thrshFlag == 1
        ANIMATSTATE.thrshFlag = [];
    end

    % Dive Activity
    if stateSelect.diveActivity == 1
        ANIMATSTATE.diveActivity = [];
    end

    % Overridinging Behavior
    if stateSelect.overrideBehavior == 1
        ANIMATSTATE.overrideBehavior = [];
    end
    
    % Offscreen Reset
    if stateSelect.offscreenReset == 1
        ANIMATSTATE.offscreenReset = [];
    end
end

% Target Depth
if stateSelect.targetDepth == 1 && ...
        scenarioParams.binOutConfig.animat.targetDepth == 1
    ANIMATSTATE.targetDepth = [];
end

% Calculated Depth
if stateSelect.calculatedDepth == 1 && scenarioParams.binOutConfig.animat.calcDepth == 1
    ANIMATSTATE.calculatedDepth = [];
end


% Calculated Depth
if stateSelect.xyDistance == 1 && ...
        scenarioParams.binOutConfig.animat.xyDistance == 1
    ANIMATSTATE.xDistance = [];
    ANIMATSTATE.yDistance = [];
end

% Risk Value
if stateSelect.riskValue == 1 && scenarioParams.binOutConfig.animat.riskValue == 1
    ANIMATSTATE.riskValue = [];
end

% Animat subID % Added for output version 4.0.  SubID incremented each time
% this animat goes off-map.
if stateSelect.subID == 1 && scenarioParams.binOutConfig.animat.subID == 1
    ANIMATSTATE.subID = [];
end


% May be included later.
%    'thrshCnt',         [], ... thrshold count



% Automatically included (for now)
    ... Values calculated or determined while reading state information
    ... from the file
ANIMATSTATE.aeAverting = []; %In aversion behavior due to acoustic exposure


if scenarioParams.binOutConfig.outputByTime == 0
    
    animatState = ReadAnimatPopulationStateByAnimat(...
        fid,...
        scenarioParams,...
        stateSelect,...
        MaxAnimatCount,...
        ANIMATSTATE);
else
    animatState = ReadAnimatPopulationStateByIteration(...
        fid,...
        scenarioParams,...
        stateSelect,...
        MaxAnimatCount,...
        ANIMATSTATE);
end

return;

% 
% as = [];
% 
% % Read in the animat states
% a = 0;
% numAnimats = scenarioParams.totalNumAnimats;
% if numAnimats > MaxAnimatCount
%     numAnimats = MaxAnimatCount;
% end
%     
% for m=1:numAnimats
%     
%     % Check if a list of animats to display was passed in.  The call to
%     % isempy() will return 0 (for false) if so.
%     isEmpty = isempty(stateSelect.animatSel);
%     if isEmpty == 0 % There is a list.
%         isEmpty = isempty(find(stateSelect.animatSel == m));
%         if isEmpty == 1 % Animat NOT found in the list
%             skipBytes = scenarioParams.regionSize.animatStates * ...
%                 scenarioParams.numIterations; 
%             fseek(fid, skipBytes, 'cof');
%             continue; % continue the for-loop.
%         end
%     end
% 
%     a = a + 1;
%     as = [as, ANIMATSTATE];
%    
%     for n=1:scenarioParams.numIterationsSaved
%         
%         % Check if a list of iterations to display was passed in.  The call
%         % to isempy() will return 0 (for false) if so.
%         if 0 == isempty(stateSelect.iterationRange)
%             if (n < stateSelect.iterationRange(1)) || (stateSelect.iterationRange(2) < n)
%                 fseek(fid, scenarioParams.regionSize.animatStates, 'cof');
%                 continue; % continue the for-loop.
%             end
%         end
%        
%         % Animat ID
%         if scenarioParams.binOutConfig.animat.ID == 1
%             if stateSelect.id == 1
%                 as(a).id = [as(a).id, fread(fid,1,'uint32')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
% 
%         % Time of Day
%         if scenarioParams.binOutConfig.animat.timeOfDay == 1
%             if stateSelect.clock == 1
%                 as(a).timeOfDay=[as(a).timeOfDay, fread(fid, 1, 'uint32')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
% 
%         % Coordinates
%         if scenarioParams.binOutConfig.animat.coordinate == 1
%             if stateSelect.coords == 1
%                 as(a).lat = [as(a).lat, fread(fid, 1, 'float')];
%                 as(a).lon = [as(a).lon, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 2*4, 'cof');
%             end
%         end
% 
%         % Depth
%         if scenarioParams.binOutConfig.animat.depth == 1
%             if stateSelect.depth == 1
%                 as(a).depth = [as(a).depth, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
% 
%         % Bearing
%         if scenarioParams.binOutConfig.animat.bearing == 1
%             if stateSelect.bearing
%                 as(a).bearing = [as(a).bearing, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         % Dive Rate
%         if scenarioParams.binOutConfig.animat.diveRate == 1
%             if stateSelect.diveRate
%                 as(a).diveRate = [as(a).diveRate, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         % Travel Rate
%         if scenarioParams.binOutConfig.animat.travelRate == 1
%             if stateSelect.travelRate
%                 as(a).travelRate = ...
%                     [as(a).travelRate, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         
%         % Cummulative Acoustic Exposure
%         if scenarioParams.binOutConfig.animat.aeCmltve == 1
%             if stateSelect.cExposure
%                 as(a).cExposure=[as(a).cExposure, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         % Instantaneous Acoustic Exposure
%         if scenarioParams.binOutConfig.animat.aeMoment == 1
%             if stateSelect.iExposure
%                 as(a).iExposure=[as(a).iExposure, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         % Acoustic source angle
%         if scenarioParams.binOutConfig.animat.aeRelAngle == 1
%             if stateSelect.relAngle == 1
%                 as(a).relAngle = [as(a).relAngle, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%       
%         % Acoustic Exposure Time Averting
%         if  scenarioParams.binOutConfig.animat.aeTimeAvrt == 1
%             timeAverting = fread(fid, 1, 'uint32');
%             if(timeAverting ~= 0)
%                 as(a).aeAverting = [as(a).aeAverting, 1];
%             else
%                 as(a).aeAverting = [as(a).aeAverting, 0];
%             end
%             if stateSelect.secAvert == 1
%                 as(a).secAvert = [as(a).secAvert, timeAverting];
%             end
%         end
%         
%         % Bathymetry Depth at animat location.
%         if scenarioParams.binOutConfig.animat.bathyDepth == 1
%             if stateSelect.bathyDepth == 1
%                 as(a).bathyDepth = ...
%                     [as(a).bathyDepth, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         % Salinity at animat location
%         if scenarioParams.binOutConfig.animat.salinity == 1
%             if stateSelect.salinity == 1
%                 as(a).salinity = [as(a).salinity, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         %  Temperature at animat location.
%         if scenarioParams.binOutConfig.animat.temperature == 1
%             if stateSelect.temperature == 1
%                 as(a).temperature= [as(a).temperature, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         % Read in packed data.
%         if scenarioParams.binOutConfig.animat.packedData
%             packedData = fread(fid, 1, 'uint32');
%             unpackedData = UnpackData(packedData);
% 
%             % Behavior State (from the unpacked data)
%             if stateSelect.behavior == 1
%                 as(a).behavior = [as(a).behavior, unpackedData.behavior];
%             end
% 
%             % Acoustice Exposure Threshold flag (from the unpacked data)
%             if stateSelect.thrshFlag == 1
%                 as(a).thrshFlag=[as(a).thrshFlag, unpackedData.threasholdFlag];
%             end
% 
%             % Dive Activity (from the unpacked data)
%             %0=SurfaceInterval, 1=bottomfollowing, 2=ascending, 3=descending,
%             %4=ascendingReversal, 5=descendingReversal, 6=beached.
%             if stateSelect.diveActivity == 1
%                 as(a).diveActivity=[as(a).diveActivity, unpackedData.activity];
%             end
% 
%             % Behavior modifiers, 5 bits (numbered 0~4) (from the unpacked
%             % data).  Bits indicate which behavior modifier is active.
%             %    1=active
%             %    0=not active.
%             %
%             % Bit 0 - acoustic aversion, bit 1 - pod follow, bit 2 shore
%             % follow, bit 3 environmental attractor depth, bit 4 environmental
%             % attractor temperature
%             if stateSelect.overrideBehavior == 1
%                 as(a).overrideBehavior = ...
%                     [as(a).overrideBehavior, unpackedData.activity];
%             end
% 
%             if stateSelect.offscreenReset == 1
%                 as(a).offscreenReset = ...
%                     [as(a).offscreenReset, unpackedData.offscreenReset];
%             end
%         end
%         
%         %  Target depth
%         if scenarioParams.binOutConfig.animat.targetDepth
%             if stateSelect.targetDepth == 1
%                 as(a).targetDepth =[as(a).targetDepth, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
% 
%         %  Calculated Depth
%         if scenarioParams.binOutConfig.animat.calcDepth
%             if stateSelect.calculatedDepth == 1
%                 as(a).calculatedDepth = ...
%                     [as(a).calculatedDepth, fread(fid, 1, 'float')];
%             else
%                 fseek(fid, 4, 'cof');
%             end
%         end
%         
%         % For now, skip over abosolute X and Y meters and current risk
%         % value (three floats so 4 bytes * 3 = 12).
%         fseek(fid, 12, 'cof');

%     end
% end
% 
% animatState = as;