function P = ReadScenarioParams(fid)
MBSBINARYOUTFILEIDENTIFIER = '3MBBinaryOutput';

MBSOUTPUTSUPERVERSION = 4;
% Updated for 3MB output version  4.xx on 02/10/13

% Scenario params are now at the top of the file, so make sure file pointer
% is at the begining.
fseek(fid, 0, 'bof');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Define some structs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Animat output configuration.
% 0=data not output, 1=data is output except where noted.
% This struct will be placed into the BINOUTCONFIG struct below.
ANIOUTCONFIG = struct(...
    'ID', 0, ... animat ID
    'subID', 0, ... animat sub/secondary ID for when it goes ofmap.
	'timeOfDay', 0, ... time of day
	'coordinate', 0, ... animat coordinate
	'depth', 0, ... animat actual depth
	'bearing', 0, ...animat bearing
	'diveRate', 0, ...animat dive rate
	'travelRate', 0, ...animat travel rate
	'aeCmltve', 0, ... animat cumulative acoustic exposure
	'aeMoment', 0, ...animat instantaneous acoustic exposure
	'aeRelAngle', 0, ...relative angle from animat to acoustic source
	'aeTimeAvrt', 0, ...animat time averting acoustic source.
	'bathyDepth', 0, ...animat bathymetry depth (depth at current location)
	'salinity', 0, ...animat salinity value at current location
	'temperature', 0, ...animat temperature value at current location
	'packedData', 0, ... animat packed data (assorted items)
	'targetDepth', 0, ...animat target dive depth
	'calcDepth', 0 ... animat calculated dive depth (varies from actual).
    );

% Overall 3MB output configuration.
% 0=data not output, 1=data is output except where noted
BINOUTCONFIG = struct(...
    'outputByTime', 0, ... 0=output by animat order, 1=output by time order.
	'anyOutput', 0, ... any output 
	'bathyMap', 0, ... bathymetry depth
	'salinityMap', 0, ... salinity map
	'temperatureMap', 0, ... temperature map
	'postRunAnalysis', 0, ... post run analysis
	'speInfAndAnimatAsscn', 0, ... species information and animat association to the species.
	'animat', ANIOUTCONFIG, ... animat output.
	'AECoordinate', 0, ... acoustic sound source coordinate.
    'mmmbPolygons', 0, ... added for 3mmb polygons
    'smbPolygons', 0 ... added for smb polygons  
    );

% Size in bytes of each of these regions.  Also used to store location in
% file (the offset from the begining) where the region is found.
BYTES = struct(...
    'sceParams', 0, ...
    'bathyMap', 0, ...
    'salinityMap', 0, ...
    'temperatureMap', 0, ...
    'postAnalysis', 0, ...
    'speDescription', 0, ...
    'animatToSpeAssoc', 0, ...
    'animatStates', 0, ...
    'acousticExposure', 0, ...
    'mmmbPolygons', 0, ... added for 3mmb polygons
    'smbPolygons', 0 ... added for smb polygons
    );

% Specific species-type configurations.
SPECIESGROUP = struct(...
   	'szGroup', 0, ...
	'lvlAphys', 0, ... Level A Physiological threshold
	'lvlBphys', 0, ... Level B Physiological threshold
	'lvlBBeh', 0, ... Level B Behavioral threshold
	'unitsPhys', 0, ... 
	'unitsBeh', 0, ... 
	'deactThreshB', 0, ... 
	'decayfncB', 0);


% This struct is associated with the header of the .3mb output file.
P = struct(... P for PARAMS
    'fileIndentifier', 0, ... character string
    'libVersionSuper', 0, ... unsigned int
    'libVersionSub', 0, ... unsigned int
    'speciesBuilderVerSuper', 0, ... unsigned int
    'speciesBuilderVerSub', 0, ... unsigned int
    'binaryOutputVerSuper', 0, ... unsigned int
    'binaryOutputVerSub', 0, ... unsigned int
    'numSpecies', 0, ... int
    'totalNumAnimats', 0, ...
    'numIterations', 0, ... this would be better named 'duration'
    'numIterationsSaved', 0, ...
    'startTime', 0, ...
    'numSpeciesGroups', 0, ...
    'bitParams1', ANIOUTCONFIG, ... just a holder for now.  Needs name changed to bitparms 1 and 2.
    'bitParams2', BINOUTCONFIG, ... just a holder for now.  Needs name changed to bitparms 1 and 2.
    'seedValue', 0, ... the seeding value used by the scenario
    'numAcousticSrcTypes', 0, ... count of the acoustic source types.
    'numAcousticSrcs', 0, ... number of acoustic sources present.
    'intervalLimitedStart',0,... starting iteration that output is limited
    'intervalLimitedValue',0,... interval at which limited output is output.
    'x16byteAlignment1', 0, ... space reserved (4 bytes) for future use.
    'reserved1', 0, ... space reserved (128 bytes) for future use.
    'NUWC_speLatinName', 0, ...   If NUWC Density Seeding: species latin name 32 bytes
    'NUWC_actualPopulation', 0, ... If NUWC Density Seeding: actual population
    'NUWC_innerBoxDensity', 0, ... If NUWC Density Seeding: inner box (shiptrack) density
    'NUWC_outerBoxDensity', 0, ... If NUWC Density Seeding: outer box density 
    'NUWC_totalAnimatsOutside', 0, ... If NUWC Density Seeding: total animats outside (ship track?) unsigned int
    'NUWC_actualAnimatsOutside', 0, ... If NUWC Density Seeding: actual animats outside (ship track?), float
    'NUWC_totalAnimatsInside', 0, ... If NUWC Density Seeding: total animats inside (ship track?) unsigned int
    'NUWC_actualAnimatsInside', 0, ... If NUWC Density Seeding: actual animats inside(ship track?), float
    'x16byteAlignment2', 0, ... space reserved (4 bytes) for future use.
    'NUWC_DensitySeedingReserved', 0, ... space reserved (128 bytes) for future use.
    'externalApplicationFileIdentifier', 0, ... character string 16 bytes
    'externalApplicationFileReserved', 0, ... 512 bytes
    'filePointers', BYTES, ...
    'regionSize', BYTES, ...
    'totalFileSize', [], ...
    'totalAnimatBytes', 0, ...
    'totalAeBytes', 0, ...
    'speciesGroup', SPECIESGROUP...
    );
    

%-------------------------------------------------------------------------%
% Read in the first 16 bytes to verify it is the file itentifer.
%P.fileIndentifier = fread(fid, 16, 'uchar');
P.fileIndentifier = fscanf(fid, '%s', 1);
if 0 ~= strcmp(MBSBINARYOUTFILEIDENTIFIER, P.fileIndentifier)
    display('The .3mb file verion is incompatable with this Matlab script verions');
    P = [];
    return;
end

% Place the file pointer 16 bytes into the file, immediately past the file
% identifier string
fseek(fid, 16, 'bof');


     %------------ 16-byte boundary -----------% 
% Read in the library version.
P.libVersionSuper = fread(fid, 1, 'uint32');   % 4 bytes
P.libVersionSub = fread(fid, 1, 'uint32');   % 4 bytes

P.speciesBuilderVerSuper = fread(fid, 1, 'uint32');   % 4 bytes
P.speciesBuilderVerSub = fread(fid, 1, 'uint32');   % 4 bytes

     %------------ 16-byte boundary -----------% 
P.binaryOutputVerSuper = fread(fid, 1, 'uint32');   % 4 bytes
P.binaryOutputVerSub = fread(fid, 1, 'uint32');   % 4 bytes
P.numSpecies = fread(fid, 1, 'uint32');
P.totalNumAnimats  = fread(fid, 1, 'int32');


% The library version may determine how data gets read in.  Add version
% checking should future versions change the scenario description portion
% of the file. 
% Todo: Write version checking code, make sure it propegates throughout
% code...


% Read the file identifier
if P.binaryOutputVerSuper ~= MBSOUTPUTSUPERVERSION
    display('wrong binary out version number for this Matlab 3mb script');
    P = [];
    return;
end

     %------------ 16-byte boundary -----------% 
P.numIterations = fread(fid, 1, 'uint32');
P.numIterationsSaved = fread(fid, 1, 'uint32');
P.startTime = fread(fid, 1, 'uint32');
P.numSpeciesGroups = fread(fid, 1, 'uint32');


% For validating order that these occur in the unsigned 32 bit integer see
% dataTypes.h in the 3MB Visual Studio project.

     %------------ 16-byte boundary -----------% 
% Components of the 3MB simulation saved to this binary output file.
% Add plus 1 to documented bits (because Matlab doesn't start at 0).
bitParams = fread(fid, 1, 'uint32');
P.binOutConfig.bathyMap = bitget(bitParams, 1);
P.binOutConfig.salinityMap = bitget(bitParams, 2);
P.binOutConfig.temperatureMap = bitget(bitParams, 3);
P.binOutConfig.postRunAnalysis = bitget(bitParams, 4);
P.binOutConfig.speInfAndAnimatAsscn = bitget(bitParams, 5);

% Saved components of animat states (booleans)
P.binOutConfig.animat.ID = bitget(bitParams, 6);
P.binOutConfig.animat.timeOfDay = bitget(bitParams, 7);
P.binOutConfig.animat.coordinate = bitget(bitParams, 8);
P.binOutConfig.animat.depth = bitget(bitParams, 9);
P.binOutConfig.animat.bearing = bitget(bitParams, 10);
P.binOutConfig.animat.diveRate = bitget(bitParams, 11);
P.binOutConfig.animat.travelRate = bitget(bitParams, 12);
P.binOutConfig.animat.aeCmltve = bitget(bitParams, 13);
P.binOutConfig.animat.aeMoment = bitget(bitParams, 14);
P.binOutConfig.animat.aeRelAngle = bitget(bitParams, 15);
P.binOutConfig.animat.aeTimeAvrt = bitget(bitParams, 16);
P.binOutConfig.animat.bathyDepth = bitget(bitParams, 17);
P.binOutConfig.animat.salinity = bitget(bitParams, 18);
P.binOutConfig.animat.temperature = bitget(bitParams, 19);
P.binOutConfig.animat.targetDepth = bitget(bitParams, 20);
P.binOutConfig.animat.packedData = bitget(bitParams, 21);
P.binOutConfig.animat.calcDepth = bitget(bitParams, 22);
P.binOutConfig.AECoordinate = bitget(bitParams, 23);
P.binOutConfig.anyOutput = bitget(bitParams, 24);
P.binOutConfig.animat.xyDistance = bitget(bitParams, 25);
P.binOutConfig.animat.riskValue = bitget(bitParams, 26);
P.binOutConfig.animat.subID = bitget(bitParams, 27); % Added for output version 4.0.
% P.binOutConfig. = bitget(bitParams, 28); Not used yet
% P.binOutConfig. = bitget(bitParams, 29); Not used yet
% P.binOutConfig. = bitget(bitParams, 30); Not used yet
% P.binOutConfig. = bitget(bitParams, 31); Not used yet
P.binOutConfig.outputByTime = bitget(bitParams, 32);


% Misc. Params
%-------------------------------------------------------------------------%
% Boolean Scenario Setup Parameters. 16 bytes, not current needed in the
% these Matlab scripts.
fseek(fid, 4, 'cof'); % the following are skipped over by this fseek().
%   P.scenarioSetup.xxx = bitget(xxx, 1); % ESME input tracking
%   P.scenarioSetup.xxx = bitget(xxx, 2); % Durationless scenario
%   P.scenarioSetup.xxx = bitget(xxx, 3); % Acoustic animat active
%   P.scenarioSetup.xxx = bitget(xxx, 4); % Distance calculation method
%   P.scenarioSetup.xxx = bitget(xxx, 5); % User current tick
%   p.scenarioSetup.xxx = bitget(xxx, 6); % Independent animat rand seed.
%   P.scenarioSetup.xxx = bitget(xxx, 7); % Output limited to acoustic source pings.
%   P.scenarioSetup.xxx = bitget(xxx, 8); % Output limited to specified intervals.
%   P.scenarioSetup.xxx = bitget(xxx, 9 ~ 32); % Not yet used in 3MB.
P.seedValue = fread(fid, 1, 'uint32'); % the seeding value
P.numAcousticSrcTypes = fread(fid, 1, 'uint32');


     %------------ 16-byte boundary -----------% 
P.numAcousticSrcs = fread(fid, 1, 'uint32');
% Interval output limitations
P.intervalLimitedStart = fread(fid, 1, 'uint32'); 
P.intervalLimitedValue = fread(fid, 1, 'uint32'); 
fseek(fid, 4, 'cof'); % 16-byte alignment

     %------------ 16-byte boundary -----------% 
% Skip over the reserved space.
fseek(fid, 128, 'cof');  % 28 bytes of reserved space for future use.
%-------------------------------------------------------------------------%


% NUWC Density Seeding Values
%-------------------------------------------------------------------------%
     %------------ 16-byte boundary -----------% 
P.NUWC_speLatinName = fread(fid, 32, 'char');
     %------------ 16-byte boundary -----------% 
P.NUWC_actualPopulation = fread(fid, 1, 'uint32');
P.NUWC_innerBoxDensity = fread(fid, 1, 'float');
P.NUWC_outerBoxDensity = fread(fid, 1, 'float');
P.NUWC_totalAnimatsOutside = fread(fid, 1, 'uint32');
     %------------ 16-byte boundary -----------% 
P.NUWC_actualAnimatsOutside = fread(fid, 1, 'uint32');
P.NUWC_totalAnimatsInside = fread(fid, 1, 'uint32');
P.NUWC_actualAnimatsInside = fread(fid, 1, 'uint32');
fseek(fid, 4, 'cof');  % 4 bytes of reserved space for future use.
%-------------------------------------------------------------------------%

%------------ 16-byte boundary -----------% 
fseek(fid, 128, 'cof');  % 128 bytes of reserved space for future NUWC

%------------ 16-byte boundary -----------% 
fseek(fid, 16, 'cof');  % External Application File Region Identifier

%------------ 16-byte boundary -----------%
fseek(fid, 512, 'cof');  % External Application File Region Identifier


P.filePointers.sceParams = fread(fid, 1, 'uint64');
P.filePointers.bathyMap = fread(fid, 1, 'uint64');
     %------------ 16-byte boundary -----------%
P.filePointers.salinityMap = fread(fid, 1, 'uint64');
P.filePointers.temperatureMap = fread(fid, 1, 'uint64');
     %------------ 16-byte boundary -----------%
P.filePointers.postAnalysis = fread(fid, 1, 'uint64');
P.filePointers.speDescription = fread(fid, 1, 'uint64');
     %------------ 16-byte boundary -----------%
P.filePointers.animatToSpeAssoc = fread(fid, 1, 'uint64');
P.filePointers.animatStates = fread(fid, 1, 'uint64');
     %------------ 16-byte boundary -----------%
P.filePointers.acousticExposure = fread(fid, 1, 'uint64');
P.filePointers.mmmbPolygons = fread(fid, 1, 'uint64');
     %------------ 16-byte boundary -----------%
P.filePointers.smbPolygons = fread(fid, 1, 'uint64');
fseek(fid, 8, 'cof');


% Region sizes
%------------ 16-byte boundary -----------%
P.regionSize.sceParams = fread(fid, 1, 'uint32');
P.regionSize.bathyMap = fread(fid, 1, 'uint32');
P.regionSize.salinityMap = fread(fid, 1, 'uint32');
P.regionSize.temperatureMap = fread(fid, 1, 'uint32');
%------------ 16-byte boundary -----------%
P.regionSize.postAnalysis = fread(fid, 1, 'uint32');
P.regionSize.speDescription = fread(fid, 1, 'uint32');
P.regionSize.animatToSpeAssoc = fread(fid, 1, 'uint32');
P.regionSize.animatStates = fread(fid, 1, 'uint32');
%------------ 16-byte boundary -----------%
P.regionSize.acousticExposure = fread(fid, 1, 'uint32');
P.regionSize.mmmbPolygons = fread(fid, 1, 'uint32');
P.regionSize.smbPolygons = fread(fid, 1, 'uint32');
fseek(fid, 4, 'cof');


     %------------ 16-byte boundary -----------%
P.totalFileSize = fread(fid, 1, 'uint64');
P.totalAnimatBytes = fread(fid, 1, 'uint64');
     %------------ 16-byte boundary -----------%
P.totalAeBytes = fread(fid, 1, 'uint64');
fseek(fid, 8, 'cof');


% Read in SPECIESGROUP (Scenario params species group) structures.
for n=1:P.numSpeciesGroups 
    P.speciesGroup(n).szGroup = fread(fid, 32, 'char');
    
	P.speciesGroup(n).lvlAphys = fread(fid, 1, 'float');
	P.speciesGroup(n).lvlBphys = fread(fid, 1, 'float');
	P.speciesGroup(n).lvlBBeh = fread(fid, 1, 'float');
	P.speciesGroup(n).deactThreshB = fread(fid, 1, 'float');
    
	P.speciesGroup(n).unitsPhys = fread(fid, 1, 'uint8');
	P.speciesGroup(n).unitsBeh = fread(fid, 1, 'uint8');
	P.speciesGroup(n).decayfncB = fread(fid, 1, 'uint8');
    fseek(fid, 1, 'cof');
    
    fseek(fid, 28, 'cof'); % skip over the 28 bytes of reserved space.
end
% Skip over the last two reserved yet unused for now SPECIESGROUP

return;
    

